@@ -110,10 +110,21 @@ class Kable:
             print(e)
             print("[KABLE] Failed to initialize Kable: Something went wrong")
 
-    def record(self, clientId: str, data, transactionId: str = str(uuid4())):
+    def record(self, clientId: str, data, transactionId: str = None):
+        """
+        Record a usage event.
+
+        :param clientId: The clientId of the customer to whom this event should be attributed.
+        :param data: Event data to record.
+        :param transactionId: A unique identifier for this event used as an idempotency key. (If not provided, a UUID will be auto-generated.)
+        """
+
         if self.debug:
             print("[KABLE] Received data to record")
 
+        if transactionId is None:
+            transactionId = str(uuid4())
+
         self.enqueueEvent(clientId=clientId, data=data,
                           transactionId=transactionId)
 
@@ -193,7 +204,7 @@ class Kable:
 
         library = {}
         library['name'] = 'kable-python-django'
-        library['version'] = '4.0.0'
+        library['version'] = '4.0.1'
 
         event['library'] = library
 
